@@ -1,4 +1,4 @@
-# Copyright (c) 2018-2020 Patricio Cubillos.
+# Copyright (c) 2018-2021 Patricio Cubillos.
 # bibmanager is open-source software under the MIT license (see LICENSE).
 
 import os
@@ -30,12 +30,13 @@ BibTeX Database Management:
   edit        Edit the bibmanager database in a text editor.
   add         Add entries into the bibmanager database.
   search      Search entries in the bibmanager database.
+  browse      Browse through the bibmanager database.
   export      Export the bibmanager database into a bib file.
   cleanup     Clean up a bibtex file of duplicates and outdated entries.
   config      Manage the bibmanager configuration parameters.
 
 LaTeX Management:
-----------------
+-----------------
   bibtex      Generate a BibTeX file from a LaTeX file.
   latex       Compile a LaTeX file with the latex command.
   pdflatex    Compile a LaTeX file with the pdflatex command.
@@ -162,8 +163,10 @@ def cli_search(args):
         return
 
     for match in matches:
-        title = textwrap.fill(f"Title: {match.title}, {match.year}",
-                              width=78, subsequent_indent='       ')
+        year = '' if match.year is None else f', {match.year}'
+        title = textwrap.fill(
+            f"Title: {match.title}{year}",
+            width=78, subsequent_indent='       ')
         author_format = 'short' if args.verb < 2 else 'long'
         authors = textwrap.fill(
             f"Authors: {match.get_authors(format=author_format)}",
@@ -179,6 +182,11 @@ def cli_search(args):
         print(f"\n{title}\n{authors}{keys}")
 
 
+def cli_browse(args):
+    """Command-line interface for database browser."""
+    bm.browse()
+
+
 def cli_export(args):
     """Command-line interface for export call."""
     path, bibfile = os.path.split(os.path.realpath(args.bibfile))
@@ -198,7 +206,7 @@ def cli_export(args):
 
 def cli_cleanup(args):
     """Command-line interface to clean up a bibfile."""
-    bibs = bm.loadfile(args.bibfile)
+    bibs = bm.read_file(args.bibfile)
     if args.ads:
         try:
             updated = am.update(base=bibs)
@@ -678,6 +686,26 @@ Examples
     search.set_defaults(func=cli_search)
 
 
+    browse_description = f"""
+{u.BOLD}Browse through the bibmanager database.{u.END}
+
+Description
+  Display the entire bibmanager database into a full-screen application
+  that lets you:
+  - Navigate through or search for specific entries
+  - Visualize the entries' full BibTeX content
+  - Select entries for printing to screen or to file
+  - Open the entries' PDF files
+  - Open the entries in ADS through the web browser
+
+Examples
+  bibm browse
+"""
+    browse = sp.add_parser('browse', description=browse_description,
+        formatter_class=argparse.RawDescriptionHelpFormatter)
+    browse.set_defaults(func=cli_browse)
+
+
     export_description = f"""
 {u.BOLD}Export the bibmanager database into a bib file.{u.END}
 
