@@ -1,4 +1,4 @@
-# Copyright (c) 2018-2020 Patricio Cubillos.
+# Copyright (c) 2018-2021 Patricio Cubillos.
 # bibmanager is open-source software under the MIT license (see LICENSE).
 
 __all__ = [
@@ -76,9 +76,13 @@ def guess_name(bib, arxiv=False):
     author = author.encode('ascii', errors='ignore').decode()
     author = re.sub('\W', '', author)
 
-    year = bib.year
+    year = '' if bib.year is None else bib.year
     guess_filename = f"{author}{year}.pdf"
 
+    if author == '' and year == '':
+        raise ValueError(
+            'Could not guess a good filename since entry does not '
+            'have author nor year fields')
     if bib.bibcode is not None:
         journal = re.sub('(\.|&)', '', bib.bibcode[4:9])
         if arxiv and journal.lower() != 'arxiv':
